@@ -33,9 +33,8 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <gio/gio.h>
-#include <gdk/gdkx.h>
+#include <gtk/gtkx.h>
 #include <gtk/gtk.h>
-#include <gconf/gconf-client.h>
 
 #include <gdk/gdk.h>
 #include <gdk/gdkkeysyms.h>
@@ -373,6 +372,7 @@ totem_embedded_set_state (TotemEmbedded *emb, TotemStates state)
 				 NULL);
 		}
 		break;
+	case TOTEM_STATE_INVALID:
 	default:
 		g_assert_not_reached ();
 		break;
@@ -581,7 +581,7 @@ totem_embedded_launch_player (TotemEmbedded *embedded,
 {
 	GList *uris = NULL;
 	GdkScreen *screen;
-	GAppLaunchContext *ctx;
+	GdkAppLaunchContext *ctx;
 	gboolean result;
 	const char *uri;
 
@@ -596,14 +596,14 @@ totem_embedded_launch_player (TotemEmbedded *embedded,
 		uri = embedded->current_uri;
 	}
 
-	ctx = G_APP_LAUNCH_CONTEXT (gdk_app_launch_context_new ());
+	ctx = gdk_display_get_app_launch_context (gtk_widget_get_display (embedded->window));
 	screen = gtk_widget_get_screen (embedded->window);
-	gdk_app_launch_context_set_screen (GDK_APP_LAUNCH_CONTEXT (ctx), screen);
+	gdk_app_launch_context_set_screen (ctx, screen);
 
-	gdk_app_launch_context_set_timestamp (GDK_APP_LAUNCH_CONTEXT (ctx), user_time);
-	gdk_app_launch_context_set_icon (GDK_APP_LAUNCH_CONTEXT (ctx), g_app_info_get_icon (embedded->app));
+	gdk_app_launch_context_set_timestamp (ctx, user_time);
+	gdk_app_launch_context_set_icon (ctx, g_app_info_get_icon (embedded->app));
 
-	result = g_app_info_launch_uris (embedded->app, uris, ctx, NULL);
+	result = g_app_info_launch_uris (embedded->app, uris, G_APP_LAUNCH_CONTEXT (ctx), NULL);
 
 	g_list_free (uris);
 
@@ -762,7 +762,7 @@ totem_embedded_set_fullscreen (TotemEmbedded *emb,
 
 		totem_fullscreen_set_fullscreen (emb->fs, FALSE);
 		gtk_widget_reparent (GTK_WIDGET (emb->bvw), container);
-		gtk_widget_hide_all (emb->fs_window);
+		gtk_widget_hide (emb->fs_window);
 
 		gtk_action_set_sensitive (fs_action, TRUE);
 	} else {
@@ -797,12 +797,12 @@ totem_embedded_set_fullscreen (TotemEmbedded *emb,
 
 static gboolean
 totem_embedded_set_time (TotemEmbedded *emb,
-			 guint64 time,
+			 guint64 _time,
 			 GError **error)
 {
-	g_message ("totem_embedded_set_time: %"G_GUINT64_FORMAT, time);
+	g_message ("totem_embedded_set_time: %"G_GUINT64_FORMAT, _time);
 
-	bacon_video_widget_seek_time (emb->bvw, time, FALSE, NULL);
+	bacon_video_widget_seek_time (emb->bvw, _time, FALSE, NULL);
 
 	return TRUE;
 }
@@ -1243,7 +1243,7 @@ popup_menu_position_func (GtkMenu *menu, gint *x, gint *y, gboolean *push_in, Gt
 	GtkTextDirection direction;
 	GtkAllocation allocation;
 
-	gtk_widget_size_request (GTK_WIDGET (menu), &menu_req);
+	gtk_widget_get_preferred_size (GTK_WIDGET (menu), NULL, &menu_req);
 
 	direction = gtk_widget_get_direction (widget);
 
@@ -1720,7 +1720,7 @@ video_widget_size_allocate_cb (GtkWidget *controls,
 			       GtkAllocation *allocation,
 			       BaconVideoWidget *bvw)
 {
-	bacon_video_widget_set_show_visuals (bvw, allocation->height > MINIMUM_VIDEO_SIZE);
+	bacon_video_widget_set_show_visualizations (bvw, allocation->height > MINIMUM_VIDEO_SIZE);
 	g_signal_handlers_disconnect_by_func (controls, G_CALLBACK (video_widget_size_allocate_cb), NULL);
 }
 
@@ -1741,31 +1741,30 @@ static gboolean
 totem_embedded_handle_key_press (TotemEmbedded *emb, GdkEventKey *event)
 {
 	switch (event->keyval) {
-	case GDK_Escape:
+	case GDK_KEY_Escape:
 		if (totem_fullscreen_is_fullscreen (emb->fs) != FALSE)
 			totem_embedded_toggle_fullscreen (emb);
 		return TRUE;
-	case GDK_F11:
-	case GDK_f:
-	case GDK_F:
+	case GDK_KEY_F11:
+	case GDK_KEY_f:
+	case GDK_KEY_F:
 		totem_embedded_toggle_fullscreen (emb);
 		return TRUE;
-	case GDK_space:
+	case GDK_KEY_space:
 		on_play_pause (NULL, emb);
 		return TRUE;
-	case GDK_Up:
+	case GDK_KEY_Up:
 		totem_embedded_action_volume_relative (emb, VOLUME_UP_OFFSET);
 		return TRUE;
-	case GDK_Down:
+	case GDK_KEY_Down:
 		totem_embedded_action_volume_relative (emb, VOLUME_DOWN_OFFSET);
 		return TRUE;
-	case GDK_Left:
-	case GDK_Right:
+	case GDK_KEY_Left:
+	case GDK_KEY_Right:
 		/* FIXME: */
-		break;
+	default:
+		return FALSE;
 	}
-
-	return FALSE;
 }
 
 static gboolean
@@ -1778,9 +1777,11 @@ totem_embedded_key_press_event (GtkWidget *widget, GdkEventKey *event,
 	if (event->state & GDK_CONTROL_MASK)
 	{
 		switch (event->keyval) {
-		case GDK_Left:
-		case GDK_Right:
+		case GDK_KEY_Left:
+		case GDK_KEY_Right:
 			return totem_embedded_handle_key_press (emb, event);
+		default:
+			break;
 		}
 	}
 
@@ -1796,7 +1797,7 @@ totem_embedded_key_press_event (GtkWidget *widget, GdkEventKey *event,
 
 static gboolean
 totem_embedded_construct (TotemEmbedded *emb,
-			  GdkNativeWindow xid,
+			  Window xid,
 			  int width,
 			  int height)
 {
@@ -1955,7 +1956,6 @@ totem_embedded_construct (TotemEmbedded *emb,
 			  G_CALLBACK (cb_vol), emb);
 
 	emb->statusbar = TOTEM_STATUSBAR (gtk_builder_get_object (emb->xml, "statusbar"));
-	gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (emb->statusbar), FALSE);
 
 	if (!emb->hidden) {
 		gtk_widget_set_size_request (emb->window, width, height);
@@ -1981,19 +1981,34 @@ totem_embedded_construct (TotemEmbedded *emb,
 
 	/* Try to make controls smaller */
 	{
-        	GtkRcStyle *rcstyle;
+		GtkCssProvider *provider;
+		gchar *css_path;
+		GError *error = NULL;
 
-		rcstyle = gtk_rc_style_new ();
-		rcstyle->xthickness = rcstyle->ythickness = 0;
+		css_path = totem_interface_get_full_path ("mozilla-viewer.css");
+		provider = gtk_css_provider_new ();
+		gtk_css_provider_load_from_path (provider, css_path, &error);
+		g_free (css_path);
 
-		gtk_widget_modify_style (emb->pp_button, rcstyle);
-		
-		child = GTK_WIDGET (gtk_builder_get_object (emb->xml, "time_hscale"));
-		gtk_widget_modify_style (child, rcstyle);
+		if (error != NULL) {
+			/* Error loading the CSS */
+			g_warning ("Couldn't load the CSS file '%s' for the browser plugin. The interface might not be styled correctly.", css_path);
+			g_error_free (error);
+		} else {
+			/* Success! Apply the styling to various widgets */
+			GtkStyleContext *context;
 
-		gtk_widget_modify_style (emb->volume, rcstyle);
+			context = gtk_widget_get_style_context (emb->pp_button);
+			gtk_style_context_add_provider (context, GTK_STYLE_PROVIDER (provider), GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 
-		g_object_unref (rcstyle);
+			context = gtk_widget_get_style_context (GTK_WIDGET (gtk_builder_get_object (emb->xml, "time_hscale")));
+			gtk_style_context_add_provider (context, GTK_STYLE_PROVIDER (provider), GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+
+			context = gtk_widget_get_style_context (emb->volume);
+			gtk_style_context_add_provider (context, GTK_STYLE_PROVIDER (provider), GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+		}
+
+		g_object_unref (provider);
 	}
 
 	/* Create the cursor before setting the state */
@@ -2071,7 +2086,7 @@ totem_embedded_set_window (TotemEmbedded *embedded,
 	embedded->width = width;
 	embedded->height = height;
 
-	totem_embedded_construct (embedded, (GdkNativeWindow) window,
+	totem_embedded_construct (embedded, (Window) window,
 				  width, height);
 
 	return TRUE;
@@ -2154,22 +2169,26 @@ totem_embedded_push_parser (gpointer data)
 	g_file_delete (file, NULL, NULL);
 	g_object_unref (file);
 
-	if (res != TOTEM_PL_PARSER_RESULT_SUCCESS) {
-		//FIXME show a proper error message
-		switch (res) {
-		case TOTEM_PL_PARSER_RESULT_UNHANDLED:
-			g_print ("url '%s' unhandled\n", emb->current_uri);
-			break;
-		case TOTEM_PL_PARSER_RESULT_ERROR:
-			g_print ("error handling url '%s'\n", emb->current_uri);
-			break;
-		case TOTEM_PL_PARSER_RESULT_IGNORED:
-			g_print ("ignored url '%s'\n", emb->current_uri);
-			break;
-		default:
-			g_assert_not_reached ();
-			;;
-		}
+	/* FIXME: show a proper error message */
+	switch (res) {
+	case TOTEM_PL_PARSER_RESULT_SUCCESS:
+		/* Success! */
+		break;
+	case TOTEM_PL_PARSER_RESULT_UNHANDLED:
+		g_print ("url '%s' unhandled\n", emb->current_uri);
+		break;
+	case TOTEM_PL_PARSER_RESULT_ERROR:
+		g_print ("error handling url '%s'\n", emb->current_uri);
+		break;
+	case TOTEM_PL_PARSER_RESULT_IGNORED:
+		g_print ("ignored url '%s'\n", emb->current_uri);
+		break;
+	case TOTEM_PL_PARSER_RESULT_CANCELLED:
+		g_print ("cancelled url '%s'\n", emb->current_uri);
+		break;
+	default:
+		g_assert_not_reached ();
+		;;
 	}
 
 	/* Check if we have anything in the playlist now */
@@ -2294,7 +2313,7 @@ int main (int argc, char **argv)
 
 		env = g_getenv ("TOTEM_EMBEDDED_GDB");
 		if (env && g_ascii_strtoull (env, NULL, 10) == 1) {
-			char *gdbargv[4];
+			const char *gdbargv[4];
 			char *gdb;
 			GError *gdberr = NULL;
 			int gdbargc = 0;
@@ -2307,7 +2326,7 @@ int main (int argc, char **argv)
 			gdbargv[gdbargc++] = NULL;
 
 			if (!g_spawn_async (NULL,
-					    gdbargv,
+					    (gchar**) gdbargv,
 					    NULL /* env */,
 					    0,
 					    NULL, NULL,
@@ -2319,6 +2338,8 @@ int main (int argc, char **argv)
 				g_print ("Sleeping....\n");
 				g_usleep (10* 1000 * 1000); /* 10s */
 			}
+
+			g_free (gdb);
 		}
 	}
 #endif
